/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { BaseClient, ClientConfig } from "@commerce-apps/core";
import { SourceCodeGroup, SourceCodeGroupSearchResult } from "./Pricing.types";
export {
  SiteId,
  SearchRequest,
  PaginatedSearchResult,
  SimpleSearchResult,
  Error,
  SourceCodeGroup,
  SourceCodeGroupSearchResult,
  SourceCodeRedirectInfo,
  SourceCodeSpecification
} from "./Pricing.types";
export declare class Client extends BaseClient {
  constructor(config: ClientConfig);
  /**
   * Deletes the source code group by ID.
   */
  deleteSourceCodeGroupsById(options?: {
    parameters?: {
      organizationId: any;
      id: any;
      siteId: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | void>;
  /**
   * Action to retrieve source code group information.
   */
  getSourceCodeGroupsById(options?: {
    parameters?: {
      organizationId: any;
      id: any;
      expand?: any;
      siteId: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | SourceCodeGroup>;
  /**
   * Updates the source code group with the specified information.
   */
  patchSourceCodeGroupsById(options: {
    parameters?: {
      organizationId: any;
      id: any;
      siteId: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | SourceCodeGroup>;
  /**
   * Creates a source code group using the information provided.
   */
  putSourceCodeGroupsById(options: {
    parameters?: {
      organizationId: any;
      id: any;
      siteId: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | SourceCodeGroup>;
  /**
    * Searches for source code groups.
 
 The query attribute specifies a complex query that can be used to narrow down the search. These are the list
 of searchable attributes:
 
 id - String
 description - String
 source_code* - String
 start_time - DateTime
 end_time - DateTime
 creation_date - DateTime
 enabled - Boolean
 active* - Boolean
 

 * - These fields can only be used in Queries as conjunctions (using AND).  If the field is used in a disjunction
 (OR) an exception will be thrown.
 
 The output of the query can also be sorted. These are the list of sortable attributes:
 
 id - String
 description - String
 enabled - Boolean
 creation_date - DateTime
 
 
 Expands that can be applied for the search request
 
 specifications - String
 
    */
  postSitesByIdSourceCodeGroupSearch(options: {
    parameters?: {
      organizationId: any;
      siteId: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | SourceCodeGroupSearchResult>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=Pricing.d.ts.map
