/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { BaseClient, ClientConfig } from "@commerce-apps/core";
import {
  CategoryProductAssignmentSearchResult,
  ProductOption,
  CategorySearchResult,
  Category,
  VariationAttribute,
  Categories,
  Variant,
  VariationGroup,
  ProductOptionValue,
  VariationAttributes,
  Catalogs,
  CatalogSearchResult,
  ProductOptions,
  Product,
  CategoryProductAssignment,
  VariationAttributeValue,
  Catalog,
  CategoryResult,
  ProductResult,
  Variants,
  VariantSearchResult,
  ProductSearchResult,
  VariationGroups
} from "./Product.types";
export {
  Error,
  BoolFilter,
  Money,
  CategoryProductAssignmentSearchResult,
  ProductOption,
  MatchAllQuery,
  Master,
  CategorySearchResult,
  FilteredQuery,
  ResultPage,
  Category,
  QueryFilter,
  VariationAttribute,
  CatalogCategoryId,
  Categories,
  SortingRule,
  ProductType,
  Variant,
  Query,
  VariationGroup,
  TermQuery,
  ProductOptionValue,
  VariationAttributes,
  SearchRequest,
  TermFilter,
  CategoryLinks,
  TextQuery,
  MarkupText,
  ImageGroup,
  Range2Filter,
  Catalogs,
  BoolQuery,
  CategoryLink,
  MediaFile,
  VariationAttributeValues,
  CatalogSearchResult,
  Site,
  NestedQuery,
  ProductOptions,
  Product,
  CategoryProductAssignment,
  VariationAttributeValue,
  Filter,
  Sort,
  ProductOptionValues,
  CategoryProductAssignmentSearchRequest,
  RangeFilter,
  CustomerListLink,
  PathRecord,
  Catalog,
  SortingRuleStep,
  SiteId,
  PaginatedSearchResult,
  SimpleSearchResult,
  OptionValue,
  CategoryResult,
  RecommendationType,
  Recommendation,
  ProductResult,
  ProductLink,
  Inventory,
  Option,
  Image,
  ProductPromotion,
  BundledProduct,
  Variants,
  VariantSearchResult,
  ProductSearchResult,
  VariationGroups
} from "./Product.types";
export declare class Client extends BaseClient {
  constructor(config: ClientConfig);
  /**
   * Action to get the list of catalog IDs with no filtering.
   */
  getCatalogs(options?: {
    parameters?: {
      select?: any;
      expand?: any;
      offset?: any;
      limit: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | Catalogs>;
  /**
   * Gets the catalog with the specified information.
   */
  getCatalog(options?: {
    parameters?: {
      catalogId: any;
      select?: any;
      expand?: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | Catalog>;
  /**
   * Updates the catalog with the specified information.
   */
  updateCatalog(options: {
    parameters?: {
      catalogId: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | Catalog>;
  /**
   * Action to get all the categories with no filtering.
   */
  getCategoriesFromCatalog(options?: {
    parameters?: {
      catalogId: any;
      select?: any;
      expand?: any;
      offset?: any;
      limit: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | Categories>;
  /**
   * Deletes the category by catalog ID and category ID.
   */
  deleteCategoryFromCatalog(options?: {
    parameters?: {
      catalogId: any;
      categoryId: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | void>;
  /**
    * Action to read an existing category within a catalog. By default, the server
 also returns the first level of sub-categories, but you can specify another level by setting the levels
 parameter. Using a large value for levels may cause performance
 issues in case of a large and deep category tree.
    */
  getCategoryFromCatalog(options?: {
    parameters?: {
      catalogId: any;
      categoryId: any;
      levels?: any;
      expand?: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | Category>;
  /**
   * Updates a catalog category using the information provided.
   */
  updateCategoryInCatalog(options: {
    parameters?: {
      catalogId: any;
      categoryId: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | Category>;
  /**
   * Creates a catalog category using the information provided.
   */
  createCategoryInCatalog(options: {
    parameters?: {
      catalogId: any;
      categoryId: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | Category>;
  /**
    * Searches for category product assignments.
 
 The query attribute specifies a complex query that can be used to narrow down the search. This is the list
 of searchable attributes:
 
 product_id - String
 product_name - String
 online_flag - Boolean
 searchable - Boolean
 valid_from - DateTime
 valid_to - DateTime
 creation_date - DateTime
 
 
 Sortable Fields:
 
 product_id - String
 product_name - String
 position - Double
 creation_date - DateTime
 
 
 Expansions that can be applied for the search request:
 
 product_base - String - This expand will enable retrieval of the following basic Product information:
 product_images - String - to fetch preview image and image groups specified for the given product
 product_all_images - String - to fetch preview image and image groups specified for the product plus images for its variants and variation groups
 product_variations - String to fetch variations related information, version 17.8+
 product_availability - String to fetch availability related information, version 17.8+
 product_categories - String to fetch category related information, version 17.8+
 product_prices - String to fetch prices related information, version 17.8+
 product_options - String to fetch options related information, version 17.8+
 product_all - String to fetch all expanded information, version 17.8+

    
        brand
        ean
      link
    long_description
      manufacturer_name
      manufacturer_sku
        name
      page_description
      page_keywords
      page_title
      searchable
    short_description
      type
      unit
        upc
    
 
    */
  searchProductsAssignedToCategory(options: {
    parameters?: {
      catalogId: any;
      categoryId: any;
      siteId?: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | CategoryProductAssignmentSearchResult>;
  /**
    * Retrieves a category product assignment.
 
 
 For example, if we have products A, B, C at positions 1, 2, 7.5, and delete assignment for product B,
  the products end up A, B, C at positions 1, null, 7.5.
    */
  getAssignedProductFromCategory(options?: {
    parameters?: {
      catalogId: any;
      categoryId: any;
      productId: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | CategoryProductAssignment>;
  /**
    * Removes a category product assignment.
 
 
 For example, if we have products A, B, C at positions 1, 2, 7.5 and delete assignment for product B,
 the products end up A, B, C at positions 1, null, 7.5.
    */
  unassignProductFromCategory(options?: {
    parameters?: {
      catalogId: any;
      categoryId: any;
      productId: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | void>;
  /**
    * Updates the category product assignment with the specified information, such as position.
  As the assigned position n is a normalized target position, we&#x27;ll make sure that the product is assigned
 to a position so that the order of positions are maintained.

 For example, if we have products A, B, C, D at positions 1, 2, 3, 4 and update product A with a  new position of 3,
 the end result is B, C, A, D with order of positions 1, 2, 3, 4. If we then update product C to no position,
 the end result is B, A, D, C with order of positions 1, 2, 3, null.

 If there are n existing positioned assignments, updating product to position &gt;&#x3D; n will end with a new assignment with a position such that the order of positions is maintained.
    */
  updateProductCategoryAssignment(options: {
    parameters?: {
      catalogId: any;
      categoryId: any;
      productId: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | CategoryProductAssignment>;
  /**
    * Creates a category product assignment using the information provided.
 
 As the assigned position n is a normalized target position, we&#x27;ll make sure that the product is assigned
 to a position so that the order of positions are maintained.
 
 For example, if we have products A, B, C at positions 1, 2, 3, and product D is assigned to
 position 2, the end result is A, D, B, C with order of positions 1, 2, 3, 4.
 
 If there are n existing positioned assignment, assigning a new product to position &gt;&#x3D; n+1 will end
 with the new assignment with position n+1.
    */
  assignProductToCategory(options: {
    parameters?: {
      catalogId: any;
      categoryId: any;
      productId: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | CategoryProductAssignment>;
  /**
    * Searches for catalog categories in the scope of catalog.
 By default, the server also returns the first level of subcategories,
  but you can specify another level by setting the levels parameter.
  Using a large value for levels may cause performance
  issues with a large and deep category tree.
 
 The query attribute specifies a complex query that can be used to narrow down the search. These are the list searchable attributes:
 
 id - String
 name - String
 description - String
 creation_date - DateTime
 online - Boolean
 parent_category_id - String
 

 The output of the query can also be sorted. These are the the sortable attributes:
 
 id - String
 name - String
 description - String
 creation_date - DateTime
 online - Boolean
 position - Double
 
    */
  searchCategoriesInCatalog(options: {
    parameters?: {
      catalogId: any;
      levels?: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | CategorySearchResult>;
  /**
    * Searches for catalogs.
 
 The query attribute specifies a complex query that can be used to narrow down the search. These are the  searchable attributes:

 id - String
 name - String
 description - String
 creation_date - DateTime
 
 
 There are two additional fields that can be used as search filters. They are not attributes in CatalogWO object,
 but can be used as filters to query catalogs based on site assignments.
 
 is_master_catalog - Boolean
 is_storefront_catalog - Boolean
 
 
 On using is_master_catalog in the search query, catalogs without any site assignments are returned.
 On using is_storefront_catalog in the search query, catalogs with one or more site assignments are returned.
 
 The output of the query can also be sorted. These are the sortable attributes:
 
 id - String
 name - String
 description - String
 creation_date - DateTime
 
    */
  searchCatalogs(options: {
    parameters?: {};
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | CatalogSearchResult>;
  /**
    * Searches for catalog categories anywhere they appear.
 By default, the server also returns the first level of subcategories,
  but you can specify another level by setting the levels parameter.
  Please note, using a large value for levels may cause performance
  issues with a large and deep category tree.
 
 The query attribute specifies a complex query that can be used to narrow down the search. These are the searchable attributes:
 
 id - String
 name - String
 description - String
 creation_date - DateTime
 online - Boolean
 catalog_id - String
 

 The output of the query can also be sorted. These are the sortable attributes:
 
 id - String
 name - String
 description - String
 creation_date - DateTime
 online - Boolean
 position - Double
 
    */
  searchCategories(options: {
    parameters?: {
      levels?: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | CategorySearchResult>;
  /**
   * Allows access to multiple products by a single request. This convenience resource should be used instead making separated requests, saving bandwidth and CPU time on the server. The URI is the same as requesting a single Product by ID, but multiple IDs wrapped by parentheses and separated are provided. If a parenthesis, or the separator, is part of the identifier itself, it has to be URL encoded. Instead of a single Product document, a result object of Product documents is returned. Note: Only products that are online and assigned to a site catalog are returned. The maximum number of IDs is 24. If none of the products requested are found, the cache-control header defaults to 60 seconds.
   */
  getProducts(options?: {
    parameters?: {
      organizationId: any;
      siteId: any;
      ids: any;
      expand?: any;
      inventoryIds?: any;
      currency?: any;
      locale?: any;
      allImages?: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | ProductResult>;
  /**
    * To access a single products resource, you construct a URL with an ID (typically a SKU) for a product. In response, the server returns a corresponding product
document, provided the product is online and assigned to a site catalog. The document contains variation attributes
(including values) and the variant matrix. This data is provided for both the master and the variant.
    */
  getProductByID(options?: {
    parameters?: {
      organizationId: any;
      id: any;
      siteId: any;
      expand?: any;
      inventoryIds?: any;
      currency?: any;
      locale?: any;
      allImages?: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | Product>;
  /**
   * When you use the URL template, the server returns multiple categories (a result object of category documents). You can use this template as a convenient way of obtaining multiple categories in a single request, instead of issuing separate requests for each category. You can specify up to 50 multiple IDs. You must enclose the list of IDs in parentheses. If a category identifier contains parenthesis or the separator sign, you must URL encode the character. The server only returns online categories.
   */
  getCategories(options?: {
    parameters?: {
      organizationId: any;
      siteId: any;
      ids: any;
      levels?: any;
      locale?: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | CategoryResult>;
  /**
    * When you use the URL template below, the server returns a category identified by its ID; by default, the server
also returns the first level of subcategories, but you can specify another level by setting the levels
parameter. The server only returns online categories.
    */
  getCategoryByID(options?: {
    parameters?: {
      organizationId: any;
      id: any;
      siteId: any;
      levels?: any;
      locale?: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | Category>;
  /**
   * Deletes the product by ID.
   */
  deleteProduct(options?: {
    parameters?: {
      organizationId: any;
      productId: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | void>;
  /**
   * Action to get product information.
   */
  getProduct(options?: {
    parameters?: {
      organizationId: any;
      productId: any;
      siteId?: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | Product>;
  /**
    * Update a product using the information provided.

Fields that can be updated:
name, page_description, long_descripton, page_title,
page_keywords, brand, ean,upc, manufacture_sku,
manufacture_name, searchable, unit, searchable,
online_flag, default_variant_id.
    */
  updateProduct(options: {
    parameters?: {
      organizationId: any;
      productId: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | Product>;
  /**
   * Creates a product using the information provided. If a product with the same unique identifier exists, it will be cleaned and overwritten unless the header x-dw-validate-existing&#x3D;true is passed in with the request.
   */
  createProduct(options: {
    parameters?: {
      organizationId: any;
      productId: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | Product>;
  /**
    * Searches product variations for master product or variation group product.
 
 The query attribute specifies a complex query that can be used to narrow down the search. This is the list
 of searchable attributes:
 
 id - String
 product_id - String
 name - String
 online - SiteSpecific Boolean
 in_stock - Boolean
 searchable - SiteSpecific Boolean
 ats - Actual available quantity to sell - Double
 variation_attribute.ATTRIBUTE_ID (Ex:variation_attribute.color) - String
 
 Sortable Fields:
 
 id - String
 product_id - String
 name - String
 online - SiteSpecific Boolean
 in_stock - Boolean
 searchable - SiteSpecific Boolean
 ats - Actual available quantity to sell - Double
 

 Note:
 The calculated value of &quot;online&quot; and &quot;searchable&quot; is used in the search/sort.
 A search/sort by the the site specific attributes require the Site ID query parameter to be set.
 They are &quot;online&quot;, &quot;in_stock&quot;, &quot;searchable&quot; and &quot;ats&quot;.
  We assume that every field that starts with variation_attribute. is searchable and dot is followed by ATTRIBUTE_ID&quot;.


 The list of expansions to retrieve product information. The expand values available are:
          
            _base - Basic product information is retrieved. This expand is included by default.
            all - All product information including the following properties are retrieved:
            
                image
                price - siteId has to be provided to see this property
                price_currency - siteId has to be provided to see this property
            
            availability - Information related to the availability of the product variation.  This expand is not included by default.
            
                ats - siteId has to be provided to see this property
                in_stock - siteId has to be provided to see this property
                online - siteId has to be provided to see this property
                searchable
            
          variations - Information related to product variation is retrieved. This expand is included by default.
            attributes - Information related to product variation attributes is retrieved. This expand is not included by default.
          
    */
  searchProductVariations(options: {
    parameters?: {
      organizationId: any;
      productId: any;
      siteId?: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | VariantSearchResult>;
  /**
   * Reads variation groups for a product master.
   */
  getVariationGroupsForMasterProduct(options?: {
    parameters?: {
      organizationId: any;
      masterProductId: any;
      siteId?: any;
      offset?: any;
      limit: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | VariationGroups>;
  /**
    * Unassign a variation group product from a product master. The variation group product is not
  deleted: it remains as a normal product after unsassign.
    */
  deleteVariationGroupForMaster(options?: {
    parameters?: {
      organizationId: any;
      masterProductId: any;
      id: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | void>;
  /**
   * Read a variation group for a product master.
   */
  getVariationGroupForMasterProduct(options?: {
    parameters?: {
      organizationId: any;
      masterProductId: any;
      id: any;
      siteId?: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | VariationGroup>;
  /**
   * Update a variation group for a product master.
   */
  updateVariationGroupInMasterProduct(options: {
    parameters?: {
      organizationId: any;
      masterProductId: any;
      id: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | VariationGroup>;
  /**
    * Assign a variation group for a product master. If the variation group product does not initially exist,
  one is created using the body passed in.
    */
  assignVariationGroupForMasterProduct(options: {
    parameters?: {
      organizationId: any;
      masterProductId: any;
      id: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | VariationGroup>;
  /**
   * Reads variation for a product master.
   */
  getVariationsForMasterProduct(options?: {
    parameters?: {
      organizationId: any;
      masterProductId: any;
      siteId?: any;
      offset?: any;
      limit: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | Variants>;
  /**
    * Unassign a variation product from a product master.  The variation product is not deleted: it remains as a
  normal product after unsassign.
    */
  deleteVariationForMaster(options?: {
    parameters?: {
      organizationId: any;
      masterProductId: any;
      id: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | void>;
  /**
   * Read a variation for a product master.
   */
  getVariationForMasterProduct(options?: {
    parameters?: {
      organizationId: any;
      masterProductId: any;
      id: any;
      siteId?: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | Variant>;
  /**
   * Update a variation for a product master.
   */
  updateVariationsInMasterProduct(options: {
    parameters?: {
      organizationId: any;
      masterProductId: any;
      id: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | Variant>;
  /**
    * Assign a variation for a product master.  If the variation product does not initially exist,
  one is created using the body passed in.
    */
  createVariationForMasterProduct(options: {
    parameters?: {
      organizationId: any;
      masterProductId: any;
      id: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | Variant>;
  /**
   * Read local and shared product options of a product.
   */
  getProductOptions(options?: {
    parameters?: {
      organizationId: any;
      productId: any;
      currency?: any;
      offset?: any;
      limit: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | ProductOptions>;
  /**
   * Deletes a local product option or unbinds a shared product option from the product.
   */
  deleteProductOption(options?: {
    parameters?: {
      organizationId: any;
      productId: any;
      id: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | void>;
  /**
   * Read a local or shared product option of a product.
   */
  getProductOption(options?: {
    parameters?: {
      organizationId: any;
      productId: any;
      id: any;
      currency?: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | ProductOption>;
  /**
   * Updates a local product option with the information provided.
   */
  updateProductOption(options: {
    parameters?: {
      organizationId: any;
      productId: any;
      id: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | ProductOption>;
  /**
   * Creates a local product option using the information provided or binds a shared product option to the product.
   */
  createProductOption(options: {
    parameters?: {
      organizationId: any;
      productId: any;
      id: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | ProductOption>;
  /**
   * Deletes a local product option value by ID.
   */
  deleteProductOptionValue(options?: {
    parameters?: {
      organizationId: any;
      id: any;
      optionId: any;
      productId: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | void>;
  /**
   * Read a local product option value of a local product option in a product.
   */
  getProductOptionValue(options?: {
    parameters?: {
      organizationId: any;
      id: any;
      optionId: any;
      productId: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | ProductOptionValue>;
  /**
   * Updates a local product option value with the information provided.
   */
  updateProductOptionValue(options: {
    parameters?: {
      organizationId: any;
      id: any;
      optionId: any;
      productId: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | ProductOptionValue>;
  /**
   * Creates a local product option value using the information provided.
   */
  createProductOptionValue(options: {
    parameters?: {
      organizationId: any;
      id: any;
      optionId: any;
      productId: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | ProductOptionValue>;
  /**
   * Action to get product variation attribute value information.
   */
  getVariationAttributeValue(options?: {
    parameters?: {
      organizationId: any;
      productId: any;
      attributeId: any;
      id: any;
      siteId?: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | VariationAttributeValue>;
  /**
   * Deletes the variation attribute value of a variation attribute bound to a master product.
   */
  deleteVariationAttributeValue(options?: {
    parameters?: {
      organizationId: any;
      productId: any;
      attributeId: any;
      id: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | void>;
  /**
   * Updates the variation attribute value of a variation attribute of a master product.
   */
  updateVariationAttributeValue(options: {
    parameters?: {
      organizationId: any;
      productId: any;
      attributeId: any;
      id: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | VariationAttributeValue>;
  /**
   * Action to create a product variation attribute value.
   */
  createVariationAttributeValue(options: {
    parameters?: {
      organizationId: any;
      productId: any;
      attributeId: any;
      id: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | VariationAttributeValue>;
  /**
   * Reads variation attributes of a product of type variant, variation master, or variation group.
   */
  getVariationAttributes(options?: {
    parameters?: {
      organizationId: any;
      productId: any;
      offset?: any;
      limit: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | VariationAttributes>;
  /**
   * Action to get variation attribute information only for master product.
   */
  getVariationAttribute(options?: {
    parameters?: {
      organizationId: any;
      productId: any;
      id: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | VariationAttribute>;
  /**
   * Deletes the variation attribute by ID.
   */
  deleteVariationAttribute(options?: {
    parameters?: {
      organizationId: any;
      productId: any;
      id: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | void>;
  /**
    * Updates the variation attribute with the specified information.
  name
  slicing
  
    */
  updateVariationAttribute(options: {
    parameters?: {
      organizationId: any;
      productId: any;
      id: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | VariationAttribute>;
  /**
   * Creates a variation attribute using the information provided.
   */
  createVariationAttribute(options: {
    parameters?: {
      organizationId: any;
      productId: any;
      id: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | VariationAttribute>;
  /**
    * &quot;Searches for products.\n\n The query attribute specifies a complex query that can be used to narrow down the search. Attributes are grouped\n into different buckets.  These are the list of searchable attributes with their corresponding buckets:\n\n Main:\n \n    id - String\n    name - String\n    online - SiteSpecific Boolean\n    searchable - SiteSpecific Boolean \n    valid_from - SiteSpefic DateTime \n    valid_to - SiteSpecfic DateTime \n    type - ProductType \n    creation_date - DateTime\n \n Catalog:\n \n    catalog_id - String\n \n Category:\n \n    category_id - String\n \n Special:\n \n    type - {\&quot;item\&quot;, \&quot;set, \&quot;bundle\&quot;, \&quot;master\&quot;, \&quot;part_of_product_set\&quot;, \&quot;bundled\&quot;, \&quot;variant\&quot;, \&quot;variation_group\&quot;, \&quot;option\&quot;, \&quot;retail_set\&quot;, \&quot;part_of_retail_set\&quot;}\n \n\n The sortable properties are:\n \n id - String\n name - String\n creation_date - DateTime\n \n\n Note that catalog_id is the id of the catalog to which products are assigned to.\n\n Only attributes in the same bucket can be joined using a disjunction (OR).\n For instance, when joining id and catalog_id above, only a conjunction is allowed (AND), whereas id\n and searchable can be joined using a disjunction because they are in the same bucket.  If an attribute\n is used in a disjunction (OR) that violates this rule, an exception will be thrown.\n\n The product search retrieves additional properties of the product when expansions are used.\n\tThe available expand attribute values are:\n \n        \t&#x27;all&#x27; will retrieve all the product properties.\n          &#x27;availability&#x27; will retrieve the following properties:\n            ats\n            in_stock\n            online\n\t\t    \n          &#x27;categories&#x27; will retrieve the following properties:\n            assigned_categories\n\t\t\t\n          &#x27;images&#x27; will retrieve the following properties:\n            image\n\t\t\t\n\t\t\t&#x27;all_images&#x27; used with images will retrieve the following properties:\n            image\n            image_groups\n\t\t\t\n          &#x27;prices&#x27; will retrieve the following properties:\n            price\n            price_currency\n\t\t\t\n          &#x27;sets&#x27; will retrieve the following properties:\n            set_products\n            product_sets\n\t\t\t\n          &#x27;bundles&#x27; will retrieve the following properties:\n            product_bundles\n            bundled_products\n            \n\t\t\t\n\n &quot;

    */
  searchProducts(options: {
    parameters?: {
      organizationId: any;
      siteId?: any;
    };
    headers?: {
      [key: string]: string;
    };
    body: object;
  }): Promise<Response | ProductSearchResult>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=Product.d.ts.map
