/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
export declare type Error = {
  type: string;
  title?: string;
  detail?: string;
  instance?: string;
};
export declare type BoolFilter = {
  operator: string;
  filters?: Array<string>;
};
export declare type Money = {
  currencyMnemonic: string;
  value: number;
};
export declare type CategoryProductAssignmentSearchResult = {
  count: number;
  hits: Array<object>;
  start: number;
  total: number;
  data?: Array<object>;
  dbStartRecord?: number;
  expand?: Array<string>;
  next?: object;
  previous?: object;
  query?: object;
  sorts?: Array<object>;
};
export declare type ProductOption = {
  customName: object;
  defaultProductOptionValue: string;
  description: object;
  id: string;
  name: string;
  selectedOptionValue: string;
  shared: boolean;
  sortingMode: string;
  values: Array<object>;
  image?: object;
};
export declare type MatchAllQuery = {};
export declare type Master = {
  masterId: string;
  orderable?: boolean;
  price?: number;
  priceMax?: number;
  prices?: object;
};
export declare type CategorySearchResult = {
  count: number;
  hits: Array<object>;
  start: number;
  total: number;
  data?: Array<object>;
  dbStartRecord?: number;
  expand?: Array<string>;
  query?: object;
  sorts?: Array<object>;
};
export declare type FilteredQuery = {
  filter: string;
  query: object;
};
export declare type ResultPage = {
  count: number;
  dbStartRecord: number;
  start: number;
};
export declare type Category = {
  id: string;
  catalogId?: string;
  categories?: Array<any>;
  creationDate?: any;
  description?: object;
  image?: string;
  lastModified?: any;
  name?: object;
  online?: boolean;
  pageDescription?: object;
  pageKeywords?: object;
  pageTitle?: object;
  parentCategoryId?: string;
  paths?: Array<object>;
  position?: number;
  sortingRules?: Array<object>;
  thumbnail?: string;
};
export declare type QueryFilter = {
  query: object;
};
export declare type VariationAttribute = {
  attributeDefinitionId: string;
  attributeDefinitionName?: object;
  defaultValue?: string;
  id?: string;
  name?: object;
  shared?: boolean;
  slicing?: boolean;
  values?: Array<object>;
  variationAttributeType?: string;
};
export declare type CatalogCategoryId = {
  catalogId: string;
  categoryId: string;
};
export declare type Categories = {
  count: number;
  data: Array<object>;
  start: number;
  total: number;
  expand?: Array<string>;
  next?: string;
  previous?: string;
};
export declare type SortingRule = {
  creationDate: any;
  description: string;
  id: string;
  productSortingRuleSteps: Array<object>;
  ruleContext: string;
  site: string;
};
export declare type ProductType = {
  master: boolean;
  bundle?: boolean;
  bundled?: boolean;
  item?: boolean;
  option?: boolean;
  partOfProductSet?: boolean;
  partOfRetailSet?: boolean;
  retailSet?: boolean;
  set?: boolean;
  variant?: boolean;
  variationGroup?: boolean;
};
export declare type Variant = {
  productId: string;
  ats?: number;
  defaultProductVariation?: boolean;
  image?: object;
  inStock?: boolean;
  online?: boolean;
  orderable?: boolean;
  price?: number;
  priceCurrency?: string;
  searchable?: object;
  variationAttributes?: Array<object>;
  variationValues?: object;
};
export declare type Query = {};
export declare type VariationGroup = {
  orderable: boolean;
  price: number;
  productId: string;
  variationValues: object;
};
export declare type TermQuery = {
  fields: Array<string>;
  operator: string;
  values?: Array<object>;
};
export declare type ProductOptionValue = {
  defaultProductOptionValue: boolean;
  id: string;
  optionPrices: Array<object>;
  skuExtension: string;
  value: object;
};
export declare type VariationAttributes = {
  count: number;
  data: Array<object>;
  expand: Array<string>;
  start: number;
  total: number;
};
export declare type SearchRequest = {
  query: object;
  count?: number;
  dbStartRecord?: number;
  expand?: Array<string>;
  select?: string;
  sorts?: Array<object>;
  start?: number;
};
export declare type TermFilter = {
  field: string;
  operator: string;
  values?: Array<object>;
};
export declare type CategoryLinks = {
  count: number;
  data: Array<object>;
  expand: Array<string>;
  start: number;
  total: number;
};
export declare type TextQuery = {
  fields: Array<string>;
  searchPhrase: string;
};
export declare type MarkupText = {
  markup: string;
  source: string;
};
export declare type ImageGroup = {
  images: Array<object>;
  variationAttributes: Array<object>;
  viewType: string;
};
export declare type Range2Filter = {
  fromField: string;
  toField: string;
  filterMode?: string;
  fromInclusive?: boolean;
  fromValue?: object;
  toInclusive?: boolean;
  toValue?: object;
};
export declare type Catalogs = {
  count: number;
  data: Array<object>;
  start: number;
  total: number;
  expand?: Array<string>;
  next?: string;
  previous?: string;
};
export declare type BoolQuery = {
  must: Array<object>;
  mustNot: Array<object>;
  should: Array<object>;
};
export declare type CategoryLink = {
  lastModified: any;
  position: number;
  sourceCatalogId: string;
  sourceCatalogName: object;
  sourceCategoryId: string;
  sourceCategoryName: object;
  targetCatalogId: string;
  targetCatalogName: object;
  targetCategoryId: string;
  targetCategoryName: object;
  type: string;
};
export declare type MediaFile = {
  alt: object;
  path: string;
  title: object;
  absUrl?: string;
  disBaseUrl?: string;
};
export declare type VariationAttributeValues = {
  count: number;
  data: Array<object>;
  expand: Array<string>;
  start: number;
  total: number;
};
export declare type CatalogSearchResult = {
  count: number;
  hits: Array<object>;
  query: object;
  start: number;
  total: number;
  data?: Array<object>;
  dbStartRecord?: number;
  expand?: Array<string>;
  next?: object;
  previous?: object;
  sorts?: Array<object>;
};
export declare type Site = {
  id: string;
  cartridges?: string;
  customerListLink?: object;
  description?: object;
  displayName?: object;
  inDeletion?: boolean;
  storefrontStatus?: string;
};
export declare type NestedQuery = {
  path: string;
  query: object;
  scoreMode?: string;
};
export declare type ProductOptions = {
  count: number;
  data: Array<object>;
  expand: Array<string>;
  start: number;
  total: number;
};
export declare type Product = {
  assignedCategories?: Array<object>;
  ats?: number;
  brand?: string;
  bundledProducts?: Array<any>;
  creationDate?: any;
  defaultVariantId?: string;
  ean?: string;
  id?: string;
  image?: object;
  imageGroups?: Array<object>;
  inStock?: boolean;
  lastModified?: any;
  longDescription?: object;
  manufacturerName?: string;
  manufacturerSku?: string;
  master?: object;
  name?: object;
  online?: boolean;
  onlineFlag?: object;
  owningCatalogId?: string;
  owningCatalogName?: object;
  pageDescription?: object;
  pageKeywords?: object;
  pageTitle?: object;
  price?: number;
  priceCurrency?: string;
  primaryCategoryId?: string;
  productBundles?: Array<any>;
  productOptions?: Array<object>;
  productSets?: Array<any>;
  searchable?: object;
  setProducts?: Array<any>;
  shortDescription?: object;
  type?: object;
  unit?: string;
  upc?: string;
  variants?: Array<object>;
  variationAttributes?: Array<object>;
  variationGroups?: Array<object>;
  variationValues?: object;
};
export declare type CategoryProductAssignment = {
  catalogId: string;
  categoryId: string;
  productId: string;
  owningCatalogName?: object;
  position?: number;
  product?: object;
  productName?: object;
};
export declare type VariationAttributeValue = {
  value: string;
  description?: object;
  image?: object;
  imageSwatch?: object;
  name?: object;
  orderable?: boolean;
  position?: number;
};
export declare type Filter = {};
export declare type Sort = {
  field: string;
  sortOrder?: string;
};
export declare type ProductOptionValues = {
  count: number;
  data: Array<object>;
  expand: Array<string>;
  start: number;
  total: number;
};
export declare type CategoryProductAssignmentSearchRequest = {
  query: object;
  count?: number;
  dbStartRecord?: number;
  expand?: Array<string>;
  select?: string;
  sorts?: Array<object>;
  start?: number;
};
export declare type RangeFilter = {
  field: string;
  from?: object;
  fromInclusive?: boolean;
  to?: object;
  toInclusive?: boolean;
};
export declare type CustomerListLink = {
  customerListId: string;
  title?: object;
};
export declare type PathRecord = {
  id: string;
  name?: object;
};
export declare type Catalog = {
  id: string;
  assignedProductCount?: number;
  assignedSites?: Array<object>;
  categoryCount?: number;
  creationDate?: any;
  description?: object;
  lastModified?: any;
  name?: object;
  online?: boolean;
  ownedProductCount?: number;
  recommendationCount?: number;
  rootCategory?: string;
};
export declare type SortingRuleStep = {
  attributeId: string;
  direction: string;
  isSystem: boolean;
  position: number;
  textRelevanceIncluded: boolean;
  typeId: string;
};
export declare type SiteId = {};
export declare type PaginatedSearchResult = {
  query: any;
  limit: number;
  offset: number;
  total: number;
  sorts?: Array<object>;
  previous?: object;
  hits?: Array<object>;
  next?: object;
};
export declare type SimpleSearchResult = {
  limit: number;
  offset: number;
  total: number;
  hits?: Array<object>;
};
export declare type OptionValue = {
  id: string;
  default?: boolean;
  name?: string;
  price?: number;
};
export declare type CategoryResult = {
  limit: number;
  data: Array<object>;
  total: number;
};
export declare type RecommendationType = {
  displayValue: string;
  value: number;
};
export declare type Recommendation = {
  recommendationType: object;
  calloutMsg?: string;
  image?: object;
  longDescription?: string;
  name?: string;
  recommendedItemId?: string;
  shortDescription?: string;
};
export declare type ProductResult = {
  limit: number;
  data: Array<object>;
  total: number;
};
export declare type ProductLink = {
  sourceProductId: string;
  sourceProductLink: string;
  targetProductId: string;
  targetProductLink: string;
  type: string;
};
export declare type Inventory = {
  id: string;
  ats?: number;
  backorderable?: boolean;
  inStockDate?: any;
  orderable?: boolean;
  preorderable?: boolean;
  stockLevel?: number;
};
export declare type Option = {
  id: string;
  description?: string;
  image?: string;
  name?: string;
  values?: Array<object>;
};
export declare type Image = {
  link: string;
  alt?: string;
  disBaseLink?: string;
  title?: string;
};
export declare type ProductPromotion = {
  calloutMsg: string;
  promotionId: string;
  promotionalPrice: number;
};
export declare type BundledProduct = {
  id: string;
  product: any;
  quantity: number;
};
export declare type Variants = {
  limit: number;
  data: Array<object>;
  offset: number;
  total: number;
};
export declare type VariantSearchResult = {
  hits: Array<object>;
  query: any;
  limit: number;
  offset: number;
  total: number;
  sorts?: Array<object>;
  previous?: object;
  next?: object;
};
export declare type ProductSearchResult = {
  hits: Array<object>;
  query: any;
  limit: number;
  offset: number;
  total: number;
  sorts?: Array<object>;
  previous?: object;
  next?: object;
};
export declare type VariationGroups = {
  limit: number;
  data: Array<object>;
  offset: number;
  total: number;
};
//# sourceMappingURL=Product.types.d.ts.map
