/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { BaseClient, ClientConfig } from "@commerce-apps/core";
import { ProductSearchResult, SuggestionResult } from "./Search.types";
export {
  ProductRef,
  SuggestedTerms,
  CategorySuggestions,
  SuggestedProduct,
  SuggestedPhrase,
  VariationAttribute,
  ProductSuggestions,
  SuggestedCategory,
  ProductType,
  BrandSuggestions,
  ProductSearchRefinementValue,
  ProductSearchSortingOption,
  SuggestedTerm,
  ProductSearchRefinement,
  CustomSuggestions,
  ProductSearchHit,
  ProductSearchResult,
  Image,
  VariationAttributeValue,
  Suggestion,
  SuggestionResult,
  ErrorResponse,
  Offset,
  Limit,
  SiteId,
  SearchRequest,
  PaginatedSearchResult,
  SimpleSearchResult
} from "./Search.types";
export declare class Client extends BaseClient {
  constructor(config: ClientConfig);
  /**
    * Provides keyword and refinement search functionality for products. Only returns the product ID, link, and name in
the product search hit. Other search hit properties can be added by using the expand parameter. The search result
contains only products that are online and assigned to site catalog.
    */
  getProductSearch(options?: {
    parameters?: {
      organizationId: any;
      siteId: any;
      q?: any;
      refine?: any;
      sort?: any;
      offset?: any;
      limit?: any;
      currency?: any;
      locale?: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | ProductSearchResult>;
  /**
   * Provides keyword search functionality for products, categories, and brands suggestions. Returns suggested products, suggested categories, and suggested brands for the given search phrase.
   */
  getSearchSuggestions(options?: {
    parameters?: {
      organizationId: any;
      siteId: any;
      q: any;
      count?: any;
      currency?: any;
      locale?: any;
    };
    headers?: {
      [key: string]: string;
    };
  }): Promise<Response | SuggestionResult>;
}
export default Client;
export { ClientConfig };
//# sourceMappingURL=Search.d.ts.map
