/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@commerce-apps/core");
const lodash_1 = tslib_1.__importDefault(require("lodash"));
class Client extends core_1.BaseClient {
  constructor(config) {
    super(config);
    if (!!!config.baseUri) {
      config.baseUri =
        "https://{shortCode}.api.commercecloud.salesforce.com/search/shopper-search/{version}/";
    }
  }
  /**
    * Provides keyword and refinement search functionality for products. Only returns the product ID, link, and name in
the product search hit. Other search hit properties can be added by using the expand parameter. The search result
contains only products that are online and assigned to site catalog.
    */
  getProductSearch(options) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId: parameters["organizationId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.get({
      client: this,
      path: "/organizations/{organizationId}/product-search",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers
    });
  }
  /**
   * Provides keyword search functionality for products, categories, and brands suggestions. Returns suggested products, suggested categories, and suggested brands for the given search phrase.
   */
  getSearchSuggestions(options) {
    const parameters = options && options.parameters ? options.parameters : {};
    const pathParameters = {
      organizationId: parameters["organizationId"]
    };
    const queryParameters = lodash_1.default.omit(
      parameters,
      lodash_1.default.keys(pathParameters)
    );
    // @ts-ignore
    return core_1.StaticClient.get({
      client: this,
      path: "/organizations/{organizationId}/search-suggestions",
      pathParameters: pathParameters,
      queryParameters: queryParameters,
      headers: (options || {}).headers
    });
  }
}
exports.Client = Client;
exports.default = Client;
//# sourceMappingURL=Search.js.map
