/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
export declare type ProductRef = {
  id: string;
};
export declare type SuggestedTerms = {
  originalTerm: string;
  terms?: Array<object>;
};
export declare type CategorySuggestions = {
  suggestedTerms: Array<object>;
  categories?: Array<object>;
  suggestedPhrases?: Array<object>;
};
export declare type SuggestedProduct = {
  currency: string;
  price: number;
  productId: string;
  productName: string;
  image?: object;
};
export declare type SuggestedPhrase = {
  exactMatch: boolean;
  phrase: string;
};
export declare type VariationAttribute = {
  id: string;
  name?: string;
  values?: Array<object>;
};
export declare type ProductSuggestions = {
  suggestedTerms: Array<object>;
  products?: Array<object>;
  suggestedPhrases?: Array<object>;
};
export declare type SuggestedCategory = {
  id: string;
  name: string;
  parentCategoryName: string;
};
export declare type ProductType = {
  bundle?: boolean;
  item?: boolean;
  master?: boolean;
  option?: boolean;
  set?: boolean;
  variant?: boolean;
  variationGroup?: boolean;
};
export declare type BrandSuggestions = {
  suggestedTerms: Array<object>;
  suggestedPhrases?: Array<object>;
};
export declare type ProductSearchRefinementValue = {
  hitCount: number;
  label: string;
  value: string;
  description?: string;
  presentationId?: string;
  values?: Array<any>;
};
export declare type ProductSearchSortingOption = {
  id: string;
  label: string;
};
export declare type SuggestedTerm = {
  completed: boolean;
  corrected: boolean;
  exactMatch: boolean;
  value: string;
};
export declare type ProductSearchRefinement = {
  attributeId: string;
  label?: string;
  values?: Array<object>;
};
export declare type CustomSuggestions = {
  suggestedTerms: Array<object>;
  customSuggestion?: string;
  suggestedPhrases?: Array<object>;
};
export declare type ProductSearchHit = {
  productId: string;
  currency?: string;
  hitType?: string;
  image?: object;
  orderable?: boolean;
  price?: number;
  priceMax?: number;
  prices?: object;
  productName?: string;
  productType?: object;
  representedProduct?: object;
  representedProducts?: Array<object>;
  variationAttributes?: Array<object>;
};
export declare type ProductSearchResult = {
  count: number;
  hits: Array<object>;
  query: string;
  refinements: Array<object>;
  searchPhraseSuggestions: object;
  sortingOptions: Array<object>;
  start: number;
  total: number;
  data?: Array<object>;
  fetchData?: number;
  selectedRefinements?: object;
  selectedSortingOption?: string;
};
export declare type Image = {
  link: string;
  alt?: string;
  disBaseLink?: string;
  title?: string;
};
export declare type VariationAttributeValue = {
  value: string;
  description?: string;
  image?: object;
  imageSwatch?: object;
  name?: string;
  orderable?: boolean;
};
export declare type Suggestion = {
  suggestedTerms: Array<object>;
  suggestedPhrases?: Array<object>;
};
export declare type SuggestionResult = {
  searchPhrase: string;
  brandSuggestions?: object;
  categorySuggestions?: object;
  productSuggestions?: object;
  customSuggestion?: object;
};
export declare type ErrorResponse = {
  type: string;
  title?: string;
  detail?: string;
  instance?: string;
};
export declare type Offset = {};
export declare type Limit = {};
export declare type SiteId = {};
export declare type SearchRequest = {
  query: any;
  limit?: number;
  sorts?: Array<object>;
  offset?: number;
};
export declare type PaginatedSearchResult = {
  query: any;
  limit: number;
  offset: number;
  total: number;
  sorts?: Array<object>;
  previous?: object;
  hits?: Array<object>;
  next?: object;
};
export declare type SimpleSearchResult = {
  limit: number;
  offset: number;
  total: number;
  hits?: Array<object>;
};
//# sourceMappingURL=Search.types.d.ts.map
